package
Version:
v0.0.0-...-6f84274
Opens a new window with list of versions in this module.
Published: May 25, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package fake provides a fake notification client for testing
type Client struct {
*Config
}
type Config struct {
CreateError string `mapstructure:"create_error"`
SendMessageError string `mapstructure:"send_message_error"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.