vcr

package
v0.0.0-...-6f84274 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 25, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package vcr provides VCR recording functionality for tests

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func MustSetupVCR

func MustSetupVCR(cassetteName string)

MustSetupVCR will create a new Recorder and add it to babyapi.DefaultMiddleware. Panics if there is an error

func StopRecorder

func StopRecorder()

StopRecorder stops the Recorder to write results to file

Types

This section is empty.

Jump to